package com.yiqi.core.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.ClothCraft;
import org.apache.ibatis.annotations.Mapper;

/**
 * 衣服工艺Mapper接口
 *
 * @author xiaohei
 * @date 2023-08-20
 */
public interface ClothCraftMapper extends BaseMapper<ClothCraft> {
    /**
     * 查询衣服工艺
     *
     * @param id 衣服工艺主键
     * @return 衣服工艺
     */
    public ClothCraft selectClothCraftById(Long id);

    /**
     * 查询衣服工艺列表
     *
     * @param clothCraft 衣服工艺
     * @return 衣服工艺集合
     */
    public List<ClothCraft> selectClothCraftList(ClothCraft clothCraft);

    /**
     * 新增衣服工艺
     *
     * @param clothCraft 衣服工艺
     * @return 结果
     */
    public int insertClothCraft(ClothCraft clothCraft);

    /**
     * 修改衣服工艺
     *
     * @param clothCraft 衣服工艺
     * @return 结果
     */
    public int updateClothCraft(ClothCraft clothCraft);

    /**
     * 删除衣服工艺
     *
     * @param id 衣服工艺主键
     * @return 结果
     */
    public int deleteClothCraftById(Long id);

    /**
     * 批量删除衣服工艺
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothCraftByIds(Long[] ids);
}
